import { type Parser as CSSParser } from "../syntax/index.js";
import { Keyword } from "./textual/keyword.js";
/**
 * {@link https://drafts.csswg.org/css-backgrounds/#typedef-box}
 *
 * @public
 */
export type Box = Keyword<"border-box"> | Keyword<"padding-box"> | Keyword<"content-box">;
/**
 * @public
 */
export declare namespace Box {
    export type JSON = Keyword.JSON<"border-box"> | Keyword.JSON<"padding-box"> | Keyword.JSON<"content-box">;
    export const parse: CSSParser<Box>;
    /**
     * {@link https://drafts.csswg.org/css-shapes/#typedef-shape-box}
     */
    export type Shape = Box | Keyword<"margin-box">;
    export namespace Shape {
        type JSON = Box.JSON | Keyword.JSON<"margin-box">;
    }
    export const parseShape: CSSParser<Shape>;
    /**
     * {@link https://drafts.fxtf.org/css-masking/#typedef-geometry-box}
     */
    export type Geometry = Shape | Keyword<"fill-box"> | Keyword<"stroke-box"> | Keyword<"view-box">;
    export namespace Geometry {
        type JSON = Shape.JSON | Keyword.JSON<"fill-box"> | Keyword.JSON<"stroke-box"> | Keyword.JSON<"view-box">;
    }
    export const parseGeometry: CSSParser<Geometry>;
    /**
     * {@link https://www.w3.org/TR/css-box-4/#typedef-visual-box}
     */
    export type VisualBox = Keyword<"content-box"> | Keyword<"padding-box"> | Keyword<"border-box">;
    namespace VisualBox {
        type JSON = Keyword.JSON<"content-box"> | Keyword.JSON<"padding-box"> | Keyword.JSON<"border-box">;
    }
    export const parseVisualBox: CSSParser<VisualBox>;
    /**
     * {@link https://www.w3.org/TR/css-box-4/#typedef-paint-box}
     */
    export type PaintBox = VisualBox | Keyword<"fill-box"> | Keyword<"stroke-box">;
    namespace PaintBox {
        type JSON = VisualBox.JSON | Keyword.JSON<"fill-box"> | Keyword.JSON<"stroke-box">;
    }
    export const parsePaintBox: CSSParser<PaintBox>;
    /**
     * {@link https://www.w3.org/TR/css-box-4/#typedef-coord-box}
     *
     * @privateRemarks
     * This is not the same type as `Geometry`. The only difference is that this type does not contain `margin-box`.
     */
    export type CoordBox = PaintBox | Keyword<"view-box">;
    export namespace CoordBox {
        type JSON = PaintBox.JSON | Keyword.JSON<"view-box">;
    }
    export const parseCoordBox: CSSParser<CoordBox>;
    export {};
}
//# sourceMappingURL=box.d.ts.map