import type { Hash } from "@siteimprove/alfa-hash";
import { type Parser as CSSParser } from "../syntax/index.js";
import { Color } from "./color/index.js";
import { Length } from "./numeric/index.js";
import type { Resolvable } from "./resolvable.js";
import { Value } from "./value.js";
/**
 * @public
 */
export declare class Shadow<H extends Length = Length, V extends Length = H, B extends Length = Length, S extends Length = Length, C extends Color = Color> extends Value<"shadow", Value.HasCalculation<[H, V, B, S, C]>> implements Resolvable<Shadow.Canonical, Shadow.Resolver> {
    static of<H extends Length = Length, V extends Length = H, B extends Length = Length, S extends Length = Length, C extends Color = Color>(horizontal: H, vertical: V, blur: B, spread: S, color: C, isInset: boolean): Shadow<H, V, B, S, C>;
    private readonly _horizontal;
    private readonly _vertical;
    private readonly _blur;
    private readonly _spread;
    private readonly _color;
    private readonly _isInset;
    protected constructor(horizontal: H, vertical: V, blur: B, spread: S, color: C, isInset: boolean);
    get horizontal(): H;
    get vertical(): V;
    get blur(): B;
    get spread(): S;
    get color(): C;
    get isInset(): boolean;
    resolve(resolver: Shadow.Resolver): Shadow.Canonical;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Shadow.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Shadow {
    type Canonical = Shadow<Length.Canonical, Length.Canonical, Length.Canonical, Length.Canonical, Color.Canonical>;
    interface JSON extends Value.JSON<"shadow"> {
        horizontal: Length.JSON;
        vertical: Length.JSON;
        blur: Length.JSON;
        spread: Length.JSON;
        color: Color.JSON;
        isInset: boolean;
    }
    /**
     * @internal
     */
    interface Options {
        withInset: boolean;
        withSpread: boolean;
    }
    type Resolver = Length.Resolver;
    function parse(options?: Options): CSSParser<Shadow>;
}
//# sourceMappingURL=shadow.d.ts.map