import { type Parser as CSSParser } from "../../syntax/index.js";
import type { Resolvable } from "../resolvable.js";
import { Ident } from "./ident.js";
/**
 * {@link https://drafts.csswg.org/css-values/#keywords}
 *
 * @public
 */
export declare class Keyword<T extends string = string> extends Ident<"keyword", T> implements Resolvable<Keyword<T>, never> {
    static of<T extends string>(value: T): Keyword<T>;
    protected constructor(value: T);
    equals(value: unknown): value is this;
}
/**
 * @public
 */
export declare namespace Keyword {
    interface JSON<T extends string = string> extends Ident.JSON<"keyword", T> {
    }
    function isKeyword(value: unknown): value is Keyword;
    /**
     * ToKeywords\<"a" | "b" | "c"\> === Keyword\<"a"\> | Keyword\<"b"\> | Keyword\<"c"\>
     */
    type ToKeywords<Words extends string> = {
        [K in Words]: Keyword<K>;
    }[Words];
    function parse<T extends string>(...keywords: Array<T>): CSSParser<ToKeywords<T>>;
}
//# sourceMappingURL=keyword.d.ts.map